/*
 * DrvUART.h
 *
 *  Created on: 2011/11/1
 *      Author: Eric.Lai
 */

#ifndef DRVUART_H_
#define DRVUART_H_
#include "HY16F188.h"

#ifndef E_FAIL
#define E_FAIL		1
#endif
#define E_DRVUART_ARGUMENT E_FAIL

#ifndef E_SUCCESS
#define E_SUCCESS		0
#endif

typedef enum
{
	E_UART_ERR_CLOCK = 2,
	E_UART_ERR_BAUDRAET,
	E_UART_ERR_PARITY,
	E_UART_ERR_DATABIT,
	E_UART_ERR_OUTPIN
} E_UART_ERROR_MESSAGE;

typedef enum
{
	B1200  =1200,
	B2400  =2400,
	B4800  =4800,
	B9600  =9600,
	B14400 =14400,
	B19200 =19200,
	B38400 =38400,
	B57600 =57600,
	B115200 =115200
} E_BAUD_RATE_SETTINGS;

typedef enum
{
	DRVUART_PARITY_NONE  = 0,
	DRVUART_PARITY_ODD,
	DRVUART_PARITY_EVEN
} E_PARITY_SETTINGS;

typedef enum
{
	DRVUART_DATABITS_8  = 0,
	DRVUART_DATABITS_9,
} E_DATABITS_SETTINGS;

#ifdef  UART_BASE
#define R_UART_CTRL1 (UART_BASE+OFFSET00)
#define R_UART_FLAG  (UART_BASE+OFFSET04)
#define R_UART_CTRL2 (UART_BASE+OFFSET08)
#define R_UART_BRGRH (UART_BASE+OFFSET0C)
#define R_UART_BRGRL (UART_BASE+OFFSET10)
#define R_UART_TXREG (UART_BASE+OFFSET14)
#define R_UART_RCREG (UART_BASE+OFFSET18)
#endif

#ifdef  CLOCK_BASE
#define R_UART_CLOCK (CLOCK_BASE+OFFSET08)
#endif

#ifdef  INTERRUPT_BASE
#define R_UART_INT_CTRL  (INTERRUPT_BASE+OFFSET00)
#endif

#ifdef GPIO_BASE
#define R_UART_GPIO     (GPIO_BASE+OFFSET44)
#endif

#define ENSP    			7
#define ENTX    			6
#define TX9   			    5
#define TX9D    		    4
#define PARITY   		    3
#define WUE		            0
#define ENSP_MASK  			(ENSP+MASK)
#define ENTX_MASK  			(ENTX+MASK)
#define TX9_MASK  		    (TX9+MASK)
#define TX9D_MASK  		    (TX9D+MASK)
#define PARITY_MASK		    (PARITY+MASK)
#define WUE_MASK	        (WUE+MASK)

#define RC9D    			6
#define PERR    			5
#define FERR   			    4
#define OERR    		    3
#define RCIDL   		    2
#define TRMT	            1
#define ABDOVF	            0
#define RC9D_MASK  			(RC9D+MASK)
#define PERR_MASK  			(PERR+MASK)
#define FERR_MASK  		    (FERR+MASK)
#define OERR_MASK  		    (OERR+MASK)
#define RCIDL_MASK 		    (RCIDL+MASK)
#define TRMT_MASK	        (TRMT+MASK)
#define ABDOVF_MASK	        (ABDOVF+MASK)

#define ENCR    			3
#define RC9      			2
#define ENADD  			    1
#define ENABD    		    0
#define ENCR_MASK  			(ENCR+MASK)
#define RC9_MASK   			(RC9+MASK)
#define ENADD_MASK 		    (ENADD+MASK)
#define ENABD_MASK 		    (ENABD+MASK)

#define USel    			21
#define UCLK_En    			20
#define UCLK_Div   			16
#define USel_MASK    		(USel+MASK)
#define UCLK_En_MASK 		(UCLK_En+MASK)
#define UCLK_Div_MASK		(UCLK_Div+MASK)
#define UCLK_Div_MAX		15

//0x40844
#define UAPS  			    1
#define UAPTOE 			    0
#define UAPS_MASK  		    (UAPS+MASK)
#define UAPTOE_MASK		    (UAPTOE+MASK)
#define UAPS_MAX  		    7

#define UART_TXIE     		19
#define UART_RXIE     		18
#define UART_TXIF     		3
#define UART_RXIF     		2
#define UART_TXIE_MASK      (UART_TXIE+MASK)
#define UART_RXIE_MASK      (UART_RXIE+MASK)
#define UART_TXIF_MASK      (UART_TXIF+MASK)
#define UART_RXIF_MASK      (UART_RXIF+MASK)

unsigned int DrvUART_Open(
		unsigned int uClock,
		unsigned int uBaudRate ,
		unsigned int uParity,
		unsigned int uDataBits,
		unsigned int uOuputPin
);
void DrvUART_Close(void);
unsigned int DrvUART_EnableInt(unsigned int uTXIE, unsigned int uRXIE);
unsigned int DrvUART_GetTxFlag();
unsigned int DrvUART_GetRxFlag();
void DrvUART_ClrTxFlag();
void DrvUART_ClrRxFlag();
unsigned int DrvUART_Read();
unsigned int DrvUART_Read9Bit();
void DrvUART_Write(unsigned int uData);
void DrvUART_EnableWakeUp();
//void DrvUART_DisableWakeUp();
void DrvUART_Enable_AutoBaudrate();
void DrvUART_DisableAutoBaudrate();
unsigned int DrvUART_GetPERR();
unsigned int DrvUART_GetFERR();
void DrvUART_ClrFERR();
unsigned int DrvUART_GetOERR();
unsigned int DrvUART_GetABDOVF();

unsigned int DrvUART_CheckTRMT(void);
unsigned int DrvUART_ClkEnable(unsigned int uclk,unsigned int uprescale);
void DrvUART_ClkDisable(void);
void DrvUART_Enable(void);
unsigned char DrvUART_ConfigIO(unsigned char ioen,unsigned int uOuputPin);
#endif /* DRVUART_H_ */


